# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto',
  package='github.com.metaprov.modelaapi.services.modelautobuilder.v1',
  syntax='proto3',
  serialized_options=b'Z:github.com/metaprov/modelaapi/services/modelautobuilder/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQgithub.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto\x12:github.com.metaprov.modelaapi.services.modelautobuilder.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xd6\x01\n\x1cListModelAutobuildersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1dListModelAutobuildersResponse\x12]\n\x05items\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderList\"y\n\x1d\x43reateModelAutobuilderRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\" \n\x1e\x43reateModelAutobuilderResponse\"y\n\x1dUpdateModelAutobuilderRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\" \n\x1eUpdateModelAutobuilderResponse\"=\n\x1aGetModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1bGetModelAutobuilderResponse\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelAutobuilderResponse2\x96\n\n\x17ModelAutobuilderService\x12\xeb\x01\n\x15ListModelAutobuilders\x12X.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest\x1aY.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/modelautobuilders\x12\xf1\x01\n\x16\x43reateModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/modelautobuilders:\x01*\x12\xec\x01\n\x13GetModelAutobuilder\x12V.github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest\x1aW.github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/modelautobuilders/{name}\x12\x93\x02\n\x16UpdateModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse\"B\x82\xd3\xe4\x93\x02<\x1a\x37/v1/modelautobuilders/{modelautobuilders.metadata.name}:\x01*\x12\x93\x02\n\x16\x44\x65leteModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse\"B\x82\xd3\xe4\x93\x02<*:/api/v1/modelautobuilders/{modelautobuilder.metadata.name}B<Z:github.com/metaprov/modelaapi/services/modelautobuilder/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=464,
)

_LISTMODELAUTOBUILDERSREQUEST = _descriptor.Descriptor(
  name='ListModelAutobuildersRequest',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=464,
)


_LISTMODELAUTOBUILDERSRESPONSE = _descriptor.Descriptor(
  name='ListModelAutobuildersResponse',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=592,
)


_CREATEMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='CreateModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=715,
)


_CREATEMODELAUTOBUILDERRESPONSE = _descriptor.Descriptor(
  name='CreateModelAutobuilderResponse',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=749,
)


_UPDATEMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='UpdateModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=872,
)


_UPDATEMODELAUTOBUILDERRESPONSE = _descriptor.Descriptor(
  name='UpdateModelAutobuilderResponse',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=906,
)


_GETMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='GetModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=969,
)


_GETMODELAUTOBUILDERRESPONSE = _descriptor.Descriptor(
  name='GetModelAutobuilderResponse',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1105,
)


_DELETEMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='DeleteModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1171,
)


_DELETEMODELAUTOBUILDERRESPONSE = _descriptor.Descriptor(
  name='DeleteModelAutobuilderResponse',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1205,
)

_LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY.containing_type = _LISTMODELAUTOBUILDERSREQUEST
_LISTMODELAUTOBUILDERSREQUEST.fields_by_name['labels'].message_type = _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY
_LISTMODELAUTOBUILDERSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDERLIST
_CREATEMODELAUTOBUILDERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER
_UPDATEMODELAUTOBUILDERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER
_GETMODELAUTOBUILDERRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER
DESCRIPTOR.message_types_by_name['ListModelAutobuildersRequest'] = _LISTMODELAUTOBUILDERSREQUEST
DESCRIPTOR.message_types_by_name['ListModelAutobuildersResponse'] = _LISTMODELAUTOBUILDERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateModelAutobuilderRequest'] = _CREATEMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['CreateModelAutobuilderResponse'] = _CREATEMODELAUTOBUILDERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderRequest'] = _UPDATEMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderResponse'] = _UPDATEMODELAUTOBUILDERRESPONSE
DESCRIPTOR.message_types_by_name['GetModelAutobuilderRequest'] = _GETMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['GetModelAutobuilderResponse'] = _GETMODELAUTOBUILDERRESPONSE
DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderRequest'] = _DELETEMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderResponse'] = _DELETEMODELAUTOBUILDERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListModelAutobuildersRequest = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest)
  })
_sym_db.RegisterMessage(ListModelAutobuildersRequest)
_sym_db.RegisterMessage(ListModelAutobuildersRequest.LabelsEntry)

ListModelAutobuildersResponse = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse)
  })
_sym_db.RegisterMessage(ListModelAutobuildersResponse)

CreateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderRequest)

CreateModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderResponse)

UpdateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderRequest)

UpdateModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderResponse)

GetModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(GetModelAutobuilderRequest)

GetModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(GetModelAutobuilderResponse)

DeleteModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderRequest)

DeleteModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderResponse)


DESCRIPTOR._options = None
_LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._options = None

_MODELAUTOBUILDERSERVICE = _descriptor.ServiceDescriptor(
  name='ModelAutobuilderService',
  full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1208,
  serialized_end=2510,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListModelAutobuilders',
    full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService.ListModelAutobuilders',
    index=0,
    containing_service=None,
    input_type=_LISTMODELAUTOBUILDERSREQUEST,
    output_type=_LISTMODELAUTOBUILDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/modelautobuilders',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService.CreateModelAutobuilder',
    index=1,
    containing_service=None,
    input_type=_CREATEMODELAUTOBUILDERREQUEST,
    output_type=_CREATEMODELAUTOBUILDERRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\"\025/v1/modelautobuilders:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService.GetModelAutobuilder',
    index=2,
    containing_service=None,
    input_type=_GETMODELAUTOBUILDERREQUEST,
    output_type=_GETMODELAUTOBUILDERRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1/modelautobuilders/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService.UpdateModelAutobuilder',
    index=3,
    containing_service=None,
    input_type=_UPDATEMODELAUTOBUILDERREQUEST,
    output_type=_UPDATEMODELAUTOBUILDERRESPONSE,
    serialized_options=b'\202\323\344\223\002<\0327/v1/modelautobuilders/{modelautobuilders.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService.DeleteModelAutobuilder',
    index=4,
    containing_service=None,
    input_type=_DELETEMODELAUTOBUILDERREQUEST,
    output_type=_DELETEMODELAUTOBUILDERRESPONSE,
    serialized_options=b'\202\323\344\223\002<*:/api/v1/modelautobuilders/{modelautobuilder.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELAUTOBUILDERSERVICE)

DESCRIPTOR.services_by_name['ModelAutobuilderService'] = _MODELAUTOBUILDERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/tenant/v1/tenant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/tenant/v1/tenant.proto',
  package='github.com.metaprov.modelaapi.services.tenant.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/metaprov/modelaapi/services/tenant/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=github.com/metaprov/modelaapi/services/tenant/v1/tenant.proto\x12\x30github.com.metaprov.modelaapi.services.tenant.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xb8\x01\n\x12ListTenantsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x13ListTenantsResponse\x12P\n\x05items\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.TenantList\"b\n\x13\x43reateTenantRequest\x12K\n\x04item\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x16\n\x14\x43reateTenantResponse\"b\n\x13UpdateTenantRequest\x12K\n\x04item\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x16\n\x14UpdateTenantResponse\"3\n\x10GetTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"n\n\x11GetTenantResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteTenantResponse2\x9d\x07\n\rTenantService\x12\xaf\x01\n\x0bListTenants\x12\x44.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest\x1a\x45.github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsResponse\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/tenants\x12\xb5\x01\n\x0c\x43reateTenant\x12\x45.github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantRequest\x1a\x46.github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/tenants:\x01*\x12\xb0\x01\n\tGetTenant\x12\x42.github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest\x1a\x43.github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/tenants/{name}\x12\xcc\x01\n\x0cUpdateTenant\x12\x45.github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantRequest\x1a\x46.github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantResponse\"-\x82\xd3\xe4\x93\x02\'\x1a\"/v1/tenants/{tenant.metadata.name}:\x01*\x12\x9f\x01\n\x0c\x44\x65leteTenant\x12\x45.github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest\x1a\x46.github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantResponse\"\x00\x42\x32Z0github.com/metaprov/modelaapi/services/tenant/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTTENANTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=401,
)

_LISTTENANTSREQUEST = _descriptor.Descriptor(
  name='ListTenantsRequest',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTTENANTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=401,
)


_LISTTENANTSRESPONSE = _descriptor.Descriptor(
  name='ListTenantsResponse',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=506,
)


_CREATETENANTREQUEST = _descriptor.Descriptor(
  name='CreateTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantRequest.item', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=606,
)


_CREATETENANTRESPONSE = _descriptor.Descriptor(
  name='CreateTenantResponse',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=630,
)


_UPDATETENANTREQUEST = _descriptor.Descriptor(
  name='UpdateTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=730,
)


_UPDATETENANTRESPONSE = _descriptor.Descriptor(
  name='UpdateTenantResponse',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=754,
)


_GETTENANTREQUEST = _descriptor.Descriptor(
  name='GetTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=807,
)


_GETTENANTRESPONSE = _descriptor.Descriptor(
  name='GetTenantResponse',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=919,
)


_DELETETENANTREQUEST = _descriptor.Descriptor(
  name='DeleteTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=921,
  serialized_end=975,
)


_DELETETENANTRESPONSE = _descriptor.Descriptor(
  name='DeleteTenantResponse',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=999,
)

_LISTTENANTSREQUEST_LABELSENTRY.containing_type = _LISTTENANTSREQUEST
_LISTTENANTSREQUEST.fields_by_name['labels'].message_type = _LISTTENANTSREQUEST_LABELSENTRY
_LISTTENANTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANTLIST
_CREATETENANTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT
_UPDATETENANTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT
_GETTENANTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT
DESCRIPTOR.message_types_by_name['ListTenantsRequest'] = _LISTTENANTSREQUEST
DESCRIPTOR.message_types_by_name['ListTenantsResponse'] = _LISTTENANTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateTenantRequest'] = _CREATETENANTREQUEST
DESCRIPTOR.message_types_by_name['CreateTenantResponse'] = _CREATETENANTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTenantRequest'] = _UPDATETENANTREQUEST
DESCRIPTOR.message_types_by_name['UpdateTenantResponse'] = _UPDATETENANTRESPONSE
DESCRIPTOR.message_types_by_name['GetTenantRequest'] = _GETTENANTREQUEST
DESCRIPTOR.message_types_by_name['GetTenantResponse'] = _GETTENANTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTenantRequest'] = _DELETETENANTREQUEST
DESCRIPTOR.message_types_by_name['DeleteTenantResponse'] = _DELETETENANTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListTenantsRequest = _reflection.GeneratedProtocolMessageType('ListTenantsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTENANTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTENANTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsRequest)
  })
_sym_db.RegisterMessage(ListTenantsRequest)
_sym_db.RegisterMessage(ListTenantsRequest.LabelsEntry)

ListTenantsResponse = _reflection.GeneratedProtocolMessageType('ListTenantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.ListTenantsResponse)
  })
_sym_db.RegisterMessage(ListTenantsResponse)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

CreateTenantResponse = _reflection.GeneratedProtocolMessageType('CreateTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.CreateTenantResponse)
  })
_sym_db.RegisterMessage(CreateTenantResponse)

UpdateTenantRequest = _reflection.GeneratedProtocolMessageType('UpdateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantRequest)
  })
_sym_db.RegisterMessage(UpdateTenantRequest)

UpdateTenantResponse = _reflection.GeneratedProtocolMessageType('UpdateTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.UpdateTenantResponse)
  })
_sym_db.RegisterMessage(UpdateTenantResponse)

GetTenantRequest = _reflection.GeneratedProtocolMessageType('GetTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.GetTenantRequest)
  })
_sym_db.RegisterMessage(GetTenantRequest)

GetTenantResponse = _reflection.GeneratedProtocolMessageType('GetTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.GetTenantResponse)
  })
_sym_db.RegisterMessage(GetTenantResponse)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

DeleteTenantResponse = _reflection.GeneratedProtocolMessageType('DeleteTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.tenant.v1.tenant_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.tenant.v1.DeleteTenantResponse)
  })
_sym_db.RegisterMessage(DeleteTenantResponse)


DESCRIPTOR._options = None
_LISTTENANTSREQUEST_LABELSENTRY._options = None

_TENANTSERVICE = _descriptor.ServiceDescriptor(
  name='TenantService',
  full_name='github.com.metaprov.modelaapi.services.tenant.v1.TenantService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1002,
  serialized_end=1927,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTenants',
    full_name='github.com.metaprov.modelaapi.services.tenant.v1.TenantService.ListTenants',
    index=0,
    containing_service=None,
    input_type=_LISTTENANTSREQUEST,
    output_type=_LISTTENANTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\r\022\013/v1/tenants',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTenant',
    full_name='github.com.metaprov.modelaapi.services.tenant.v1.TenantService.CreateTenant',
    index=1,
    containing_service=None,
    input_type=_CREATETENANTREQUEST,
    output_type=_CREATETENANTRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\013/v1/tenants:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTenant',
    full_name='github.com.metaprov.modelaapi.services.tenant.v1.TenantService.GetTenant',
    index=2,
    containing_service=None,
    input_type=_GETTENANTREQUEST,
    output_type=_GETTENANTRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/tenants/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTenant',
    full_name='github.com.metaprov.modelaapi.services.tenant.v1.TenantService.UpdateTenant',
    index=3,
    containing_service=None,
    input_type=_UPDATETENANTREQUEST,
    output_type=_UPDATETENANTRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\032\"/v1/tenants/{tenant.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTenant',
    full_name='github.com.metaprov.modelaapi.services.tenant.v1.TenantService.DeleteTenant',
    index=4,
    containing_service=None,
    input_type=_DELETETENANTREQUEST,
    output_type=_DELETETENANTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENANTSERVICE)

DESCRIPTOR.services_by_name['TenantService'] = _TENANTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto',
  package='github.com.metaprov.modelaapi.services.featurepipeline.v1',
  syntax='proto3',
  serialized_options=b'Z9github.com/metaprov/modelaapi/services/featurepipeline/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nOgithub.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto\x12\x39github.com.metaprov.modelaapi.services.featurepipeline.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd1\x01\n\x1aListFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x1bListFeaturePipelineResponse\x12X\n\x05items\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineList\"s\n\x1c\x43reateFeaturePipelineRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x1f\n\x1d\x43reateFeaturePipelineResponse\"s\n\x1cUpdateFeaturePipelineRequest\x12S\n\x04item\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x1f\n\x1dUpdateFeaturePipelineResponse\"<\n\x19GetFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x1aGetFeaturePipelineResponse\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteFeaturePipelineResponse\"\x1e\n\x1cPauseFeaturePipelineResponse\">\n\x1bPauseFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1dResumeFeaturePipelineResponse\"?\n\x1cResumeFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\x97\r\n\x16\x46\x65\x61turePipelineService\x12\xe3\x01\n\x14ListFeaturePipelines\x12U.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest\x1aV.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/featurepipelines\x12\xeb\x01\n\x15\x43reateFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/featurepipelines:\x01*\x12\xe6\x01\n\x12GetFeaturePipeline\x12T.github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest\x1aU.github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/featurepipelines/{name}\x12\x83\x02\n\x15UpdateFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse\"7\x82\xd3\xe4\x93\x02\x31\x1a,/v1/featurepipelines/{feature.metadata.name}:\x01*\x12\xcc\x01\n\x15\x44\x65leteFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse\"\x00\x12\xf2\x01\n\x14PauseFeaturePipeline\x12V.github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest\x1aW.github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse\")\x82\xd3\xe4\x93\x02#\"!/v1/featurepipelines/{name}:pause\x12\xf5\x01\n\x15ResumeFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse\")\x82\xd3\xe4\x93\x02#\"!/v1/featurepipelines/{name}:pauseB;Z9github.com/metaprov/modelaapi/services/featurepipeline/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTFEATUREPIPELINEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=452,
)

_LISTFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='ListFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTFEATUREPIPELINEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=452,
)


_LISTFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='ListFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=573,
)


_CREATEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=690,
)


_CREATEFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='CreateFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=723,
)


_UPDATEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=840,
)


_UPDATEFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='UpdateFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=873,
)


_GETFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=935,
)


_GETFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='GetFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1064,
)


_DELETEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1129,
)


_DELETEFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='DeleteFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1162,
)


_PAUSEFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='PauseFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1194,
)


_PAUSEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='PauseFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1258,
)


_RESUMEFEATUREPIPELINERESPONSE = _descriptor.Descriptor(
  name='ResumeFeaturePipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1291,
)


_RESUMEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='ResumeFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1356,
)

_LISTFEATUREPIPELINEREQUEST_LABELSENTRY.containing_type = _LISTFEATUREPIPELINEREQUEST
_LISTFEATUREPIPELINEREQUEST.fields_by_name['labels'].message_type = _LISTFEATUREPIPELINEREQUEST_LABELSENTRY
_LISTFEATUREPIPELINERESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINELIST
_CREATEFEATUREPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE
_UPDATEFEATUREPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE
_GETFEATUREPIPELINERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE
DESCRIPTOR.message_types_by_name['ListFeaturePipelineRequest'] = _LISTFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturePipelineResponse'] = _LISTFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRequest'] = _CREATEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateFeaturePipelineResponse'] = _CREATEFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRequest'] = _UPDATEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineResponse'] = _UPDATEFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['GetFeaturePipelineRequest'] = _GETFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturePipelineResponse'] = _GETFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRequest'] = _DELETEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineResponse'] = _DELETEFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseFeaturePipelineResponse'] = _PAUSEFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseFeaturePipelineRequest'] = _PAUSEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ResumeFeaturePipelineResponse'] = _RESUMEFEATUREPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['ResumeFeaturePipelineRequest'] = _RESUMEFEATUREPIPELINEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREPIPELINEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRequest)
_sym_db.RegisterMessage(ListFeaturePipelineRequest.LabelsEntry)

ListFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineResponse)

CreateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRequest)

CreateFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineResponse)

UpdateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRequest)

UpdateFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineResponse)

GetFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRequest)

GetFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(GetFeaturePipelineResponse)

DeleteFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRequest)

DeleteFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineResponse)

PauseFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('PauseFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(PauseFeaturePipelineResponse)

PauseFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('PauseFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(PauseFeaturePipelineRequest)

ResumeFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(ResumeFeaturePipelineResponse)

ResumeFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(ResumeFeaturePipelineRequest)


DESCRIPTOR._options = None
_LISTFEATUREPIPELINEREQUEST_LABELSENTRY._options = None

_FEATUREPIPELINESERVICE = _descriptor.ServiceDescriptor(
  name='FeaturePipelineService',
  full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1359,
  serialized_end=3046,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFeaturePipelines',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.ListFeaturePipelines',
    index=0,
    containing_service=None,
    input_type=_LISTFEATUREPIPELINEREQUEST,
    output_type=_LISTFEATUREPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/v1/featurepipelines',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.CreateFeaturePipeline',
    index=1,
    containing_service=None,
    input_type=_CREATEFEATUREPIPELINEREQUEST,
    output_type=_CREATEFEATUREPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\024/v1/featurepipelines:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.GetFeaturePipeline',
    index=2,
    containing_service=None,
    input_type=_GETFEATUREPIPELINEREQUEST,
    output_type=_GETFEATUREPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/v1/featurepipelines/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.UpdateFeaturePipeline',
    index=3,
    containing_service=None,
    input_type=_UPDATEFEATUREPIPELINEREQUEST,
    output_type=_UPDATEFEATUREPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\0021\032,/v1/featurepipelines/{feature.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.DeleteFeaturePipeline',
    index=4,
    containing_service=None,
    input_type=_DELETEFEATUREPIPELINEREQUEST,
    output_type=_DELETEFEATUREPIPELINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.PauseFeaturePipeline',
    index=5,
    containing_service=None,
    input_type=_PAUSEFEATUREPIPELINEREQUEST,
    output_type=_PAUSEFEATUREPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/v1/featurepipelines/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService.ResumeFeaturePipeline',
    index=6,
    containing_service=None,
    input_type=_RESUMEFEATUREPIPELINEREQUEST,
    output_type=_RESUMEFEATUREPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/v1/featurepipelines/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATUREPIPELINESERVICE)

DESCRIPTOR.services_by_name['FeaturePipelineService'] = _FEATUREPIPELINESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto',
  package='github.com.metaprov.modelaapi.services.modelcompilerrun.v1',
  syntax='proto3',
  serialized_options=b'Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQgithub.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto\x12:github.com.metaprov.modelaapi.services.modelcompilerrun.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xd6\x01\n\x1cListModelCompilerRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x03 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1dListModelCompilerRunsResponse\x12]\n\x05items\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunList\"\x1a\n\x18ModelCompilerRunResponse\"y\n\x1d\x43reateModelCompilerRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\" \n\x1e\x43reateModelCompilerRunResponse\"y\n\x1dUpdateModelCompilerRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\" \n\x1eUpdateModelCompilerRunResponse\"=\n\x1aGetModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1bGetModelCompilerRunResponse\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelCompilerRunResponse2\xbd\n\n\x17ModelCompilerRunService\x12\xf5\x01\n\x15ListModelCompilerRuns\x12X.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest\x1aY.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1alpha1/modelcompilerruns\x12\xfb\x01\n\x16\x43reateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1alpha1/modelcompilerruns:\x01*\x12\xf6\x01\n\x13GetModelCompilerRun\x12V.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest\x1aW.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1alpha1/modelcompilerruns/{name}\x12\x9c\x02\n\x16UpdateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse\"K\x82\xd3\xe4\x93\x02\x45\x1a@/api/v1alpha1/modelcompilerruns/{modelcompilerrun.metadata.name}:\x01*\x12\x93\x02\n\x16\x44\x65leteModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse\"B\x82\xd3\xe4\x93\x02<*:/api/v1/modelcompilerruns/{modelcompilerrun.metadata.name}B<Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=464,
)

_LISTMODELCOMPILERRUNSREQUEST = _descriptor.Descriptor(
  name='ListModelCompilerRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=464,
)


_LISTMODELCOMPILERRUNSRESPONSE = _descriptor.Descriptor(
  name='ListModelCompilerRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=592,
)


_MODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='ModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=620,
)


_CREATEMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='CreateModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=743,
)


_CREATEMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='CreateModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=777,
)


_UPDATEMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='UpdateModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=900,
)


_UPDATEMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='UpdateModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=934,
)


_GETMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='GetModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=997,
)


_GETMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='GetModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1133,
)


_DELETEMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='DeleteModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1199,
)


_DELETEMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='DeleteModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1201,
  serialized_end=1233,
)

_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY.containing_type = _LISTMODELCOMPILERRUNSREQUEST
_LISTMODELCOMPILERRUNSREQUEST.fields_by_name['labels'].message_type = _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY
_LISTMODELCOMPILERRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUNLIST
_CREATEMODELCOMPILERRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUN
_UPDATEMODELCOMPILERRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUN
_GETMODELCOMPILERRUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUN
DESCRIPTOR.message_types_by_name['ListModelCompilerRunsRequest'] = _LISTMODELCOMPILERRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListModelCompilerRunsResponse'] = _LISTMODELCOMPILERRUNSRESPONSE
DESCRIPTOR.message_types_by_name['ModelCompilerRunResponse'] = _MODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateModelCompilerRunRequest'] = _CREATEMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['CreateModelCompilerRunResponse'] = _CREATEMODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunRequest'] = _UPDATEMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunResponse'] = _UPDATEMODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['GetModelCompilerRunRequest'] = _GETMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['GetModelCompilerRunResponse'] = _GETMODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunRequest'] = _DELETEMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunResponse'] = _DELETEMODELCOMPILERRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListModelCompilerRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsRequest)
_sym_db.RegisterMessage(ListModelCompilerRunsRequest.LabelsEntry)

ListModelCompilerRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsResponse)

ModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('ModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(ModelCompilerRunResponse)

CreateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunRequest)

CreateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunResponse)

UpdateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunRequest)

UpdateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunResponse)

GetModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(GetModelCompilerRunRequest)

GetModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(GetModelCompilerRunResponse)

DeleteModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunRequest)

DeleteModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunResponse)


DESCRIPTOR._options = None
_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._options = None

_MODELCOMPILERRUNSERVICE = _descriptor.ServiceDescriptor(
  name='ModelCompilerRunService',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1236,
  serialized_end=2577,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListModelCompilerRuns',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.ListModelCompilerRuns',
    index=0,
    containing_service=None,
    input_type=_LISTMODELCOMPILERRUNSREQUEST,
    output_type=_LISTMODELCOMPILERRUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/api/v1alpha1/modelcompilerruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.CreateModelCompilerRun',
    index=1,
    containing_service=None,
    input_type=_CREATEMODELCOMPILERRUNREQUEST,
    output_type=_CREATEMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\037/api/v1alpha1/modelcompilerruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.GetModelCompilerRun',
    index=2,
    containing_service=None,
    input_type=_GETMODELCOMPILERRUNREQUEST,
    output_type=_GETMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/api/v1alpha1/modelcompilerruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.UpdateModelCompilerRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEMODELCOMPILERRUNREQUEST,
    output_type=_UPDATEMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002E\032@/api/v1alpha1/modelcompilerruns/{modelcompilerrun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.DeleteModelCompilerRun',
    index=4,
    containing_service=None,
    input_type=_DELETEMODELCOMPILERRUNREQUEST,
    output_type=_DELETEMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002<*:/api/v1/modelcompilerruns/{modelcompilerrun.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELCOMPILERRUNSERVICE)

DESCRIPTOR.services_by_name['ModelCompilerRunService'] = _MODELCOMPILERRUNSERVICE

# @@protoc_insertion_point(module_scope)
